@@ -72,6 +72,18 @@ theta_222csLAR_int <- c(phi10_222, vec(A11_222), vec(A12_222), vec(W_222), 0.2,
 
 theta_222tcsLAR_int <- c(theta_222csLAR_int, 10, 20) # SStMVAR
 
+# p=2, M=2, d=2, model="GMVAR", constraints=C_222, same_means=list(1:2), weight_constraints=0.6,
+# structural_pars=list(W=W_222, fixed_lambdas=c(7, 3))
+theta_222cmwsF <- c(phi10_222, vec(A11_222), vec(A12_222), vec(W_222))
+
+# p=2, M=2, d=2, model="GMVAR", constraints=C_222, weight_constraints=0.6,
+# structural_pars=list(W=W_222, fixed_lambdas=c(7, 3))
+theta_222cwsF <- c(phi10_222, c(1.79, 3.00), vec(A11_222), vec(A12_222), vec(W_222))
+
+# p=1, M=2, d=2, model="StMVAR", weight_constraints=0.83, structural_pars=list(W=W_122, fixed_lambdas=c(7, 3))
+params12twsF <- c(phi10_122, phi20_122, vec(A11_122), vec(A21_122), vec(W_122), 10, 1000)
+
+
 test_that("GSMVAR works correctly", {
   mod122 <- GSMVAR(gdpdef, p=1, M=2, params=params122)
   mod122t <- GSMVAR(gdpdef, p=1, M=2, params=params122t, model="StMVAR")
@@ -98,7 +110,8 @@ test_that("GSMVAR works correctly", {
 
   # Same_means
   mod222c_int <- GSMVAR(gdpdef, p=2, M=2, params=theta_222c_int, parametrization="mean", constraints=C_222, same_means=list(1:2))
-  mod222gsc_int <- GSMVAR(gdpdef, p=2, M=c(1, 1), params=theta_222gsc_int, model="G-StMVAR", parametrization="mean", constraints=C_222, same_means=list(1:2))
+  mod222gsc_int <- GSMVAR(gdpdef, p=2, M=c(1, 1), params=theta_222gsc_int, model="G-StMVAR", parametrization="mean",
+                          constraints=C_222, same_means=list(1:2))
   mod222csLAR_int <- GSMVAR(gdpdef, p=2, M=2, params=theta_222csLAR_int, parametrization="mean", constraints=C_222,
                            structural_pars=list(W=W_222, C_lambda=C_lambda_222), same_means=list(1:2))
   mod222tcsLAR_int <- GSMVAR(gdpdef, p=2, M=2, params=theta_222tcsLAR_int, model="StMVAR", parametrization="mean", constraints=C_222,
@@ -106,9 +119,15 @@ test_that("GSMVAR works correctly", {
   expect_equal(mod222c_int$params, theta_222c_int)
   expect_equal(mod222gsc_int$params, theta_222gsc_int)
   expect_equal(mod222tcsLAR_int$params, theta_222tcsLAR_int)
+
+  # Fixed alphas and lambdas
+  mod222cmwsF <- GSMVAR(gdpdef, p=2, M=2, params=theta_222cmwsF, model="GMVAR", constraints=C_222, same_means=list(1:2),
+                        weight_constraints=0.6, parametrization="mean", structural_pars=list(W=W_222, fixed_lambdas=c(7, 3)))
+  expect_equal(mod222cmwsF$params, theta_222cmwsF)
 })
 
 
+
 test_that("add_data works correctly", {
   mod122 <- GSMVAR(p=1, M=2, d=2, params=params122)
   mod122_2 <- add_data(data=gdpdef, gsmvar=mod122)
@@ -135,6 +154,12 @@ test_that("add_data works correctly", {
                          parametrization="mean", constraints=C_222, same_means=list(1:2))
   mod222tc_int2 <- add_data(data=gdpdef, gsmvar=mod222tc_int)
   expect_equal(mod222tc_int2$data, gdpdef)
+
+  # Fixed alphas and lambdas
+  mod222cmwsF <- GSMVAR(p=2, M=2, d=2, params=theta_222cmwsF, model="GMVAR", constraints=C_222, same_means=list(1:2),
+                        weight_constraints=0.6, parametrization="mean", structural_pars=list(W=W_222, fixed_lambdas=c(7, 3)))
+  mod222cmwsF <- add_data(data=gdpdef, gsmvar=mod222cmwsF)
+  expect_equal(mod222cmwsF$data, gdpdef)
 })
 
 
@@ -170,13 +195,20 @@ test_that("swap_parametrization works correctly", {
                                        0.36539, -2.16435, 1, 0.37), tolerance=1e-4)
   expect_equal(mod122gscsLAR_2$params, c(-6.05, 5.45, -7.21, 8.37, 0.9, 0.3, -0.3, 0.9, -0.89246, -0.71805,
                                           0.36539, -2.16435, 1, 0.37, 3), tolerance=1e-4)
+
+  # Fixed alphas and lambdas
+  mod222cwsF <- GSMVAR(p=2, M=2, d=2, params=theta_222cwsF, model="GMVAR", constraints=C_222, weight_constraints=0.6,
+                        parametrization="intercept", structural_pars=list(W=W_222, fixed_lambdas=c(7, 3)))
+  mod222cwsF_2 <- swap_parametrization(mod222cwsF)
+  expect_equal(mod222cwsF_2$params, c(-5, 123, 9.66667, 140.33333, 1.25, 0.06, 0.04, 1.34, -0.29, -0.08, -0.05, -0.36,
+                                      -0.89246, -0.71805, 0.36539, -2.16435), tolerance=1e-4)
 })
 
 
 test_that("alt_gsmvar does not throw errors", {
   gsmvar11 <- suppressMessages(fitGSMVAR(gdpdef[1:20,], p=1, M=1, ncalls=2, ncores=1, maxit=1, seeds=1:2, print_res=FALSE, ngen=1))
-  tmp <- alt_gsmvar(gsmvar11, which_round=1, calc_cond_moments=FALSE, calc_std_errors=FALSE)
-  expect_true(TRUE) # There needs to be a test inside each test_that
+  expect_silent(alt_gsmvar(gsmvar11, which_round=1, calc_cond_moments=FALSE, calc_std_errors=FALSE))
+  #expect_true(TRUE) # There needs to be a test inside each test_that
 })
 
 # GMVAR(1,2), d=2 model:
@@ -210,6 +242,13 @@ params112chol <- c(0.649528, 0.066507, 0.288525, 0.021766, -0.144026, 0.897103,
 mod112chol <- GSMVAR(gdpdef, p=1, M=1, params=params112chol)
 mod112chols <- gsmvar_to_sgsmvar(mod112chol, cholesky=TRUE)
 
+# p=2, M=2, d=2, constraints=C_222, weight_constraints=0.368
+params222cw <- c(1.031, 2.356, 1.786, 3.000, 1.250, 0.060, 0.036, 1.335, -0.290, -0.083, -0.047, -0.356,
+                 0.934, -0.152, 5.201, 5.883, 3.560, 9.799)
+mod222cw <- GSMVAR(p=2, M=2, d=2, params=params222cw, constraints=C_mat, weight_constraints=0.368)
+mod222cws <- gsmvar_to_sgsmvar(mod222cw)
+
+
 test_that("gsmvar_to_sgsmvar works correctly", {
   expect_equal(mod122s$params, c(0.623, -0.129, 3.245, 7.913, 0.959, 0.089, -0.006, 1.006, 0.952, -0.037, -0.019, 0.943,
                                  1.31216, 0.87892, -0.15571, 2.2431, 3.99732, 1.79808, 0.789), tolerance=1e-3)
@@ -225,6 +264,8 @@ test_that("gsmvar_to_sgsmvar works correctly", {
   expect_equal(mod112chols$params, c(0.649528, 0.066507, 0.288525, 0.021766, -0.144026, 0.897103, 0.775752,
                                      -0.003795, 0.259248), tolerance=1e-4)
   expect_equal(mod112chols$model$structural_pars$W, matrix(c(1, NA, 0, 1), nrow=2))
+  expect_equal(mod222cws$params, c(1.031, 2.356, 1.786, 3, 1.25, 0.06, 0.036, 1.335, -0.29, -0.083, -0.047, -0.356, 0.89382,
+                                   0.71976, -0.36753, 2.16401, 7.14351, 1.30222), tolerance=1e-3)
 })
 
 
@@ -240,6 +281,19 @@ mod112_2 <- reorder_W_columns(mod112, perm=2:1)
 mod112t <- GSMVAR(gdpdef, p=1, M=1, params=c(params112, 10), model="StMVAR", structural_pars=list(W=W112))
 mod112t_2 <- reorder_W_columns(mod112t, perm=2:1)
 
+# Fixed alphas and lambdas mods
+mod222cmwsF <- GSMVAR(gdpdef, p=2, M=2, params=theta_222cmwsF, model="GMVAR", constraints=C_222, same_means=list(1:2),
+                      weight_constraints=0.6, parametrization="mean", structural_pars=list(W=W_222, fixed_lambdas=c(7, 3)))
+mod222cwsF <- GSMVAR(gdpdef, p=2, M=2, params=theta_222cwsF, model="GMVAR", constraints=C_222,
+                     weight_constraints=0.6, structural_pars=list(W=W_222, fixed_lambdas=c(7, 3)))
+mod12twsF <- suppressWarnings(GSMVAR(gdpdef, p=1, M=2, params=params12twsF, model="StMVAR",
+                                     weight_constraints=0.83, structural_pars=list(W=W_122, fixed_lambdas=c(7, 3))))
+mod122twsF <- mod12twsF
+
+mod222cmwsF_2 <- reorder_W_columns(mod222cmwsF, perm=2:1)
+mod222cwsF_2 <- reorder_W_columns(mod222cwsF, perm=2:1)
+mod122twsF_2 <- suppressWarnings(reorder_W_columns(mod122twsF, perm=2:1))
+
 
 # p=2, M=2, d=2, constraints=C_222, structural_pars=list(W=W_222), same_means=list(1:2)
 theta_222csAR_int <- c(phi10_222, vec(A11_222), vec(A12_222), vec(W_222), 0.2, 0.4, alpha1_222)
@@ -258,6 +312,7 @@ mod222tcsAR_int <- GSMVAR(gdpdef, p=2, M=2, params=c(theta_222csAR_int, 10, 20),
 mod222tcsAR_int2 <- reorder_W_columns(mod222tcsAR_int, perm=2:1)
 
 
+
 test_that("reorder_W_columns works correctly", {
   expect_equal(mod222cs2$params, c(1.031, 2.356, 1.786, 3, 1.25, 0.06, 0.036, 1.335, -0.29, -0.083, -0.047, -0.356, -0.36753,
                                    2.16401, 0.89382, 0.71976, 1.30222, 7.14351, 0.368), tolerance=1e-3)
@@ -272,6 +327,13 @@ test_that("reorder_W_columns works correctly", {
   expect_equal(mod222tcsAR_int2$params,
                c(1.0300000, 2.3600000, 1.2500000, 0.0600000, 0.0400000, 1.3400000, -0.2900000, -0.0800000, -0.0500000, -0.3600000, 0.3653923,
                  -2.1643472, -0.8924620, -0.7180539, 0.4000000, 0.2000000, 0.3700000, 10, 20), tolerance=1e-6)
+
+  expect_equal(mod222cmwsF_2$params, c(1.03, 2.36, 1.25, 0.06, 0.04, 1.34, -0.29, -0.08, -0.05, -0.36,
+                                       0.365392, -2.164347, -0.892462, -0.718054), tolerance=1e-3)
+  expect_equal(mod222cwsF_2$params, c(1.03, 2.36, 1.79, 3, 1.25, 0.06, 0.04, 1.34, -0.29, -0.08, -0.05,
+                                      -0.36, 0.365392, -2.164347, -0.892462, -0.718054), tolerance=1e-3)
+  expect_equal(mod122twsF_2$params, c(1.03, 2.36, 1.79, 3, 0.9, 0.3, -0.3, 0.9, 0.9, 0.3, -0.3, 0.9, 0.365392,
+                                      -2.164347, -0.892462, -0.718054, 10, 1000), tolerance=1e-3)
 })
 
 mod222cs3 <- swap_W_signs(mod222cs, which_to_swap=1:2)
@@ -281,6 +343,9 @@ mod222csAR_int3 <- swap_W_signs(mod222csAR_int, which_to_swap=1)
 mod222gscsAR_int3 <- swap_W_signs(mod222gscsAR_int, which_to_swap=1)
 mod222tcsAR_int3 <- swap_W_signs(mod222tcsAR_int, which_to_swap=1)
 
+mod222cmwsF_3 <- swap_W_signs(mod222cmwsF, which_to_swap=1)
+mod222cwsF_3 <- swap_W_signs(mod222cwsF, which_to_swap=1:2)
+mod122twsF_3 <- suppressWarnings(swap_W_signs(mod122twsF, which_to_swap=2))
 
 test_that("swap_W_signs works correctly", {
   expect_equal(mod222cs3$params, c(1.031, 2.356, 1.786, 3, 1.25, 0.06, 0.036, 1.335, -0.29, -0.083, -0.047, -0.356, -0.89382,
@@ -298,6 +363,13 @@ test_that("swap_W_signs works correctly", {
   expect_equal(mod222tcsAR_int3$params,
                c(1.0300000, 2.3600000, 1.2500000, 0.0600000, 0.0400000, 1.3400000, -0.2900000, -0.0800000, -0.0500000, -0.3600000,
                  0.8924620, 0.7180539, 0.3653923, -2.1643472, 0.2000000, 0.4000000, 0.3700000, 10, 20), tolerance=1e-6)
+
+  expect_equal(mod222cmwsF_3$params, c(1.03, 2.36, 1.25, 0.06, 0.04, 1.34, -0.29, -0.08, -0.05, -0.36,
+                                       0.8924620, 0.7180539, 0.3653923, -2.1643472), tolerance=1e-3)
+  expect_equal(mod222cwsF_3$params, c(1.03, 2.36, 1.79, 3, 1.25, 0.06, 0.04, 1.34, -0.29, -0.08, -0.05,
+                                      -0.36, 0.8924620, 0.7180539, -0.3653923, 2.1643472), tolerance=1e-3)
+  expect_equal(mod122twsF_3$params, c(1.03, 2.36, 1.79, 3, 0.9, 0.3, -0.3, 0.9, 0.9, 0.3, -0.3, 0.9, -0.8924620,
+                                      -0.7180539, -0.3653923, 2.1643472, 10, 1000), tolerance=1e-3)
 })
 
 
@@ -305,11 +377,14 @@ test_that("update_numtols works correctly", {
   mod112t_4 <- update_numtols(mod112t, stat_tol=1e-5, posdef_tol=1e-6, df_tol=1e-7)
   mod222csLAR_4 <- update_numtols(mod222csAR_int, stat_tol=1e-5, posdef_tol=1e-6, df_tol=1e-7)
   mod222gscsLAR_4 <- update_numtols(mod222gscsAR_int, stat_tol=1e-5, posdef_tol=1e-6, df_tol=1e-7)
+  mod122twsF_4 <- suppressWarnings(update_numtols(mod122twsF, stat_tol=1e-5, posdef_tol=1e-6, df_tol=1e-7))
+
   new_tols <- list(stat_tol=1e-5, posdef_tol=1e-6, df_tol=1e-7)
 
   expect_equal(mod112t_4$num_tols, new_tols, tolerance=1e-8)
   expect_equal(mod222csLAR_4$num_tols, new_tols, tolerance=1e-8)
   expect_equal(mod222gscsLAR_4$num_tols, new_tols, tolerance=1e-8)
+  expect_equal(mod122twsF_4$num_tols, new_tols, tolerance=1e-8)
 })
 
 
@@ -320,13 +395,16 @@ params12 <- c(0.5453, 0.1157, 0.331, 0.0537, -0.0422, 0.7089, 0.4181, 0.0018,
 mod12t <- suppressWarnings(GSMVAR(gdpdef, p=1, M=2, params=c(params12, 7, 90000), model="StMVAR"))
 mod12gs <- suppressWarnings(GSMVAR(gdpdef, p=1, M=c(1, 1), params=c(params12, 90), model="G-StMVAR"))
 
-test_that("sgmvar_to_gstmvar works correctly", {
+
+test_that("stmvar_to_gstmvar works correctly", {
   new_mod12t_1 <- suppressMessages(stmvar_to_gstmvar(mod12t, maxdf=100, maxit=1))
   new_mod12t_2 <- suppressMessages(stmvar_to_gstmvar(mod12t, maxdf=5, maxit=1))
   new_mod12t_3 <- suppressWarnings(suppressMessages(stmvar_to_gstmvar(mod12t, maxdf=90001, maxit=1)))
   new_mod12gs_1 <- suppressWarnings(suppressMessages(stmvar_to_gstmvar(mod12gs, maxdf=100, maxit=1)))
   new_mod12gs_2 <- suppressWarnings(suppressMessages(stmvar_to_gstmvar(mod12gs, maxdf=50, maxit=1)))
 
+  new_mod12twsF <- suppressWarnings(suppressMessages(stmvar_to_gstmvar(mod12twsF, maxdf=100, estimate=FALSE)))
+
   expect_equal(new_mod12t_1$model$model, "G-StMVAR")
   expect_equal(new_mod12t_1$model$M, c(1, 1))
   expect_equal(new_mod12t_2$model$model, "GMVAR")
@@ -337,4 +415,10 @@ test_that("sgmvar_to_gstmvar works correctly", {
   expect_equal(new_mod12gs_1$model$M, c(1, 1))
   expect_equal(new_mod12gs_2$model$model, "GMVAR")
   expect_equal(new_mod12gs_2$model$M, 2)
+  expect_equal(new_mod12twsF$model$model, "G-StMVAR")
+  expect_equal(new_mod12twsF$model$M, c(1, 1))
+  expect_equal(new_mod12twsF$params,
+               stmvarpars_to_gstmvar(p=1, M=2, d=2, params=params12twsF, model="StMVAR", weight_constraints=0.83,
+                                     structural_pars=list(W=W_122, fixed_lambdas=c(7, 3)), maxdf=100)$params, tolerance=1e-5)
+
 })
