@@ -209,8 +209,29 @@ theta_123csLAR_int <- c(phi10_123, vec(A11_123), vec(W_123), 1, 2, alpha1_123) #
 theta_123tcsLAR_int <- c(theta_123csLAR_int, 10, 20) # SStMVAR
 
 
+# p=1, M=2, d=2, model="StMVAR", weight_constraints=0.6, structural_pars=list(W=W_122, fixed_lambdas=c(7, 4))
+theta_122twsF <- c(phi10_122, phi20_122, vec(A11_122), vec(A21_122), Wvec(W_122), 11, 12)
+
+# p=1, M=2, d=2, model="GMVAR", constraints=C_122, same_means=list(1:2), parametrization="mean"
+C_122 <- rbind(diag(1*2^2), diag(1*2^2))
+theta_122cm <- c(0.804831, 0.54569, 0.303675, 0.023641, -0.132479, 0.852206, 0.287346, 0.004983,
+                 0.025076, 1.119671, -0.017208, 0.142676, 0.647105)
+theta_122cm_expanded <- c(0.804831, 0.54569, # mu
+                          0.303675, 0.023641, -0.132479, 0.852206, # A
+                          0.287346, 0.004983, 0.025076, # Omega 1
+                          0.804831, 0.54569, # mu
+                          0.303675, 0.023641, -0.132479, 0.852206, # A
+                          1.119671, -0.017208, 0.142676,  # Omega 2
+                          0.647105) # Alpha
+
+
 
 test_that("pick_Ami works correctly", {
+  expect_equal(pick_Ami(p=1, M=2, d=2, params=theta_122cm_expanded, m=1, i=1, unvec=FALSE),
+               c(0.303675, 0.023641, -0.132479, 0.852206))
+  expect_equal(pick_Ami(p=1, M=2, d=2, params=theta_122cm_expanded, m=2, i=1, unvec=FALSE),
+               c(0.303675, 0.023641, -0.132479, 0.852206))
+
   expect_equal(pick_Ami(p=1, M=1, d=2, params=theta_112, m=1, i=1, unvec=TRUE), A11_112)
 
   expect_equal(pick_Ami(p=1, M=2, d=2, params=theta_122, m=1, i=1, unvec=TRUE), A11_122)
@@ -371,8 +392,10 @@ test_that("pick_allA works correctly", {
   expect_equal(pick_allA(p=2, M=1, d=3, params=theta_213s, structural_pars=list(W=W_213))[, , 2, 1], A12_213)
 })
 
-
 test_that("pick_phi0 works correctly", {
+  expect_equal(pick_phi0(p=1, M=2, d=2, params=theta_122cm_expanded)[, 1], c(0.804831, 0.54569))
+  expect_equal(pick_phi0(p=1, M=2, d=2, params=theta_122cm_expanded)[, 2], c(0.804831, 0.54569))
+
   expect_equal(pick_phi0(p=1, M=1, d=2, params=theta_112)[, 1], phi10_112)
 
   expect_equal(pick_phi0(p=1, M=2, d=2, params=theta_122)[, 1], phi10_122)
@@ -468,6 +491,9 @@ test_that("pick_all_phi0_A works correctly", {
 
 
 test_that("pick_Omegas works correctly", {
+  expect_equal(pick_Omegas(p=1, M=2, d=2, params=theta_122cm_expanded)[, , 1], unvech(d=2, a=c(0.287346, 0.004983, 0.025076)))
+  expect_equal(vech(pick_Omegas(p=1, M=2, d=2, params=theta_122cm_expanded)[, , 2]), c(1.119671, -0.017208, 0.142676))
+
   expect_equal(pick_Omegas(p=1, M=1, d=2, params=theta_112)[, , 1], Omega1_112)
 
   expect_equal(pick_Omegas(p=1, M=2, d=2, params=theta_122)[, , 1], Omega1_122)
@@ -604,7 +630,13 @@ theta_112sWC <- c(phi10_112, vec(A11_112), Wvec(W_112)) # SGMVAR
 theta_213tsWC <- c(theta_213sWC, 10) # StMVAR
 theta_112tsWC <- c(theta_112sWC, 15) # StMVAR
 
+
 test_that("pick_regime works correctly", {
+  expect_equal(pick_regime(p=1, M=2, d=2, params=theta_122twsF, m=1, weight_constraints=0.6, model="StMVAR",
+                           structural_pars=list(W=W_122, fixed_lambdas=c(7, 4))), c(phi10_122, vec(A11_122), 11))
+  expect_equal(pick_regime(p=1, M=2, d=2, params=theta_122twsF, m=2, weight_constraints=0.6, model="StMVAR",
+                           structural_pars=list(W=W_122, fixed_lambdas=c(7, 4))), c(phi20_122, vec(A21_122), 12))
+
   expect_equal(pick_regime(p=1, M=1, d=2, params=theta_112, m=1), upsilon1_112)
   expect_equal(pick_regime(p=1, M=2, d=2, params=theta_122, m=1), upsilon1_122)
   expect_equal(pick_regime(p=1, M=2, d=2, params=theta_122, m=2), upsilon2_122)
@@ -784,6 +816,12 @@ mod222gscsLAR <- GSMVAR(p=2, M=c(1, 1), d=2, params=c(theta_222csLAR, 20), model
                         structural_pars=list(W=W_222, C_lambda=C_lambda_222)) # SG-StMVAR
 
 
+# p=1, M=2, d=2, model="StMVAR", weight_constraints=0.6, structural_pars=list(W=W_122, fixed_lambdas=c(7, 4))
+theta_122twsF_2 <- c(phi10_122, phi20_122, 0.3*vec(A11_122), 0.12*vec(A21_122), Wvec(W_122), 11, 12)
+mod_122twsF <- GSMVAR(p=1, M=2, d=2, params=theta_122twsF_2, model="StMVAR", weight_constraints=0.6,
+                      structural_pars=list(W=W_122, fixed_lambdas=c(7, 4)))
+
+
 test_that("get_boldA_eigens works correctly", {
   expect_equal(get_boldA_eigens(mod222)[,1], c(0.9917467, 0.9112338, 0.4566127, 0.2464068), tolerance=1e-5)
   expect_equal(get_boldA_eigens(mod222t)[2,], c(0.9112338, 0.9285837), tolerance=1e-5)
@@ -795,6 +833,8 @@ test_that("get_boldA_eigens works correctly", {
   expect_equal(get_boldA_eigens(mod112tcsWAR)[,1], c(0.3615207, 0.2284793), tolerance=1e-5)
   expect_equal(get_boldA_eigens(mod222csLAR)[,2], c(0.9819784, 0.9215689, 0.4260533, 0.2603994), tolerance=1e-5)
   expect_equal(get_boldA_eigens(mod222gscsLAR)[4,], c(.2603994, 0.2603994), tolerance=1e-5)
+
+  expect_equal(c(get_boldA_eigens(mod_122twsF)), c(0.3146969, 0.2853031, 0.1258788, 0.1141212), tolerance=1e-5)
 })
 
 test_that("get_omega_eigens works correctly", {
@@ -808,6 +848,8 @@ test_that("get_omega_eigens works correctly", {
   expect_equal(get_omega_eigens(mod112tcsWAR)[,1], c(5.2052628, 0.9247372), tolerance=1e-5)
   expect_equal(get_omega_eigens(mod222csLAR)[,2], c(2.0610439, 0.1882761), tolerance=1e-5)
   expect_equal(get_omega_eigens(mod222gscsLAR)[,1], c(5.3657061, 0.9039939), tolerance=1e-5)
+
+  expect_equal(c(get_omega_eigens(mod_122twsF)), c(4.9179538, 0.9178462, 21.2972299, 5.9345701), tolerance=1e-5)
 })
 
 
